'''
nester.py contains the function print_lol
'''
def print_lol(the_list, indent=False, depth=0):
    '''
    print_lol is a function that takes a list and prints each element
    it takes a depth with default 0 paramater, for how many indents
    '''
    for each_item in the_list:
        if isinstance(each_item, list):
            print_lol(each_item, indent, depth+1)
        else:
            if indent:
                for i in range(depth):
                    print("\t", end='')
            print(each_item)
